@@ -4,7 +4,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.45'; # VERSION
+our $VERSION = '0.46'; # VERSION
 
 # ABSTRACT: A collection of perlmv scriptlets
 
@@ -124,15 +124,18 @@ EOT
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 App::perlmv::scriptlets::std - A collection of perlmv scriptlets
 
 =head1 VERSION
 
-version 0.45
+This document describes version 0.46 of App::perlmv::scriptlets::std (from Perl distribution App-perlmv), released on 2014-05-15.
 
 =head1 SCRIPTLETS
 
@@ -205,16 +208,31 @@ L<Text::Unaccent::PurePerl>.
 If you have cool scriptlets to share, feel free to contact me so I can
 include them here.
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/App-perlmv>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/sharyanto/perl-App-perlmv>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-perlmv>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
 Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2014 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
